@@ -120,7 +120,7 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
-        <source>Widget opacity %</source>
+        <source>Widget opacity</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
